\NeedsTeXFormat{LaTeX2e}[1994/12/01]
\ProvidesClass{sciencestep}
\LoadClass[openany, twoside, a5paper, article, 10pt]{extbook}
\RequirePackage[T2A]{fontenc}
\RequirePackage[pdftex]{graphicx}
\usepackage[utf8]{inputenc}
\usepackage[english, russian]{babel}

\ProcessOptions\relax

\usepackage{indentfirst}
\usepackage{setspace}
\usepackage{mdwlist}
\usepackage{float}
\usepackage{url}
\sloppy
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{amsthm}
\usepackage{amscd}
\usepackage{bm}

%	a5paper: 148 x 210
%	print area: 110 x 180
%	top = bottom = (210 - 180) / 2 = 15
%	left = right = (148 - 110) / 2 = 19
\special{papersize=148mm,210mm}
\usepackage[%
   left=1.9cm,% 1.9
    top=1.5cm,% 1.5 
    right=1.9cm,% 1.9
    bottom=1.5cm,% 1.5
    headsep=0.2cm,%
    footskip=0.5cm,%
    includehead,%
    includefoot]{geometry}
\textwidth 110mm
\textheight 170mm
\linespread{1.0}

\newcommand{\Booktitle}{Научно-практическая конференция <<Шаг в науку>>}
\usepackage{fancyhdr}
\usepackage{setspace}
\lhead{}
\rhead{}
\lfoot{}
\cfoot{\thepage}
\rfoot{}
\pagestyle{fancy}

\newcommand{\ENGLISH}[1]{#1}%\selectlanguage{english}{#1}\selectlanguage{russian}}
\newcommand*{\HM}[1]{#1\nobreak\discretionary{}{\hbox{\(\mathsurround=0pt #1\)}}{}}

\newcommand{\processlist}[3][\relax]{% 
  \def\listfinish{#1}% 
  \long\def\listact{#2}% 
  \processnext#3\listfinish} 

\newcommand{\processnext}[1]{% 
  \if\listfinish#1\empty\else\listact{#1}\expandafter\processnext\fi} 


\newcommand{\CurTitle}{TITLE}

\newcommand\Title[2]{%		{Title}{Ivanov I.I.}
    \par
    \begin{centering}
        \smallskip
        {
            \large
            \textbf{\textsc{#1}}\nopagebreak \\
        }
    \end{centering}
    \nopagebreak
    \addcontentsline{toc}{section}{ {#1} (\textit{#2})}
    %\processlist{\index}{#2}
    \renewcommand{\CurTitle}{#1}
    \@afterheading 
    \smallskip
    \nopagebreak 
}
\makeatother

%
%
%


\makeatletter
\newcommand\Author[7]{% 1{Ivanov Ivan Ivanovich}2{Student}3{CMC MSU}4{Moscow}5{Russia}6{ivan@mail.ru}7{Supervisorov~Supervisor~Supervisorovich}
	\begin{center}
	\par {\textit{\textbf{#1}}\\
	{\footnotesize \textit{#2}}}\\
	{\footnotesize \textit {#3, #4, #5}} \\
	{\footnotesize \textit{E-mail:} \texttt{#6}}\\
	\vspace{1ex}
	\par {\textit{\textbf{Научный руководитель~---}} \textit{#7}}\\
    \end{center}
    %\addtocontents{toc}{\noindent\small\hspace{-0.4cm}\textit{#1}}
    %\addcontentsline{toc}{OurOwnSection}{\small\CurTitle}
    \nopagebreak
}
\newcounter{local}


\newcommand\PrintAuthor[1]{%
	\textit{\textbf{#1}}$^{\text{\arabic{local}}}$\\\
	\addtocounter{local}{1}
}
\newcommand\PrintInfo[1]{%
	{\footnotesize\arabic{local}: \textit{#1}}\\\
	\addtocounter{local}{1}
}

\newcommand\AuthorM[3]{% 1{Ivanov Ivan Ivanovich}2{Student}3{CMC MSU}4{Moscow}5{Russia}6{ivan@mail.ru}
	
	\setcounter{local}{1}
	\begin{center}
	\par 
	\setcounter{local}{1} \processlist{\PrintAuthor}{#1}\\
	\setcounter{local}{1} \processlist{\PrintInfo}{#2}
	{\footnotesize \textit{E-mail:} \texttt{#3}}\\
	\end{center}
	\nopagebreak
}
\def\changemargin#1#2{\list{}{\rightmargin#2\leftmargin#1}\item[]}
\let\endchangemargin=\endlist 

%   Generate the environment for the abstract:
\newcommand\summaryname{Аннотация}
\newenvironment{Abstract}%
    {\small\begin{center}%
    \bfseries{\summaryname}\end{center}\begin{changemargin}{1cm}{1cm} }{\end{changemargin}}

%
%		Literature and so
%
\makeatletter
\newcommand{\References}{
    \smallskip
    \nopagebreak
    \centerline{\textbf{Литература}}
    \nopagebreak
    \smallskip
    \@afterheading
}
\makeatother

\newenvironment{references}{\References\begin{enumerate*}}{\end{enumerate*}}
\newcommand{\Source}{\item}

\makeatletter
\renewenvironment{thebibliography}[1]
{ %\refname
	\smallskip
	\nopagebreak
	\centerline{\\ \textbf{\refname}}
	\nopagebreak
	\smallskip
	\@afterheading
	
	%\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
	\list{
		\@biblabel{\@arabic\c@enumiv}
	}%
	{
		\settowidth\labelwidth{\@biblabel{#1}}%
		\leftmargin\labelwidth
		\advance\leftmargin\labelsep
		\@openbib@code
		\usecounter{enumiv}%
		\let\p@enumiv\@empty
		\renewcommand\theenumiv{\@arabic\c@enumiv}}%
	\sloppy
	\clubpenalty4000
	\@clubpenalty \clubpenalty
	\widowpenalty4000%
	\sfcode`\.\@m}
{\def\@noitemerr
	{\@latex@warning{Empty `thebibliography' environment}}%
	\endlist}
\makeatother

\makeatother

\newcommand{\PicPath}{}

\makeatother

\makeatletter
\newcommand{\Picture}[3]{%
\begin{figure}[H]
  \begin{center}
  \includegraphics[keepaspectratio, width=#3\textwidth]{\PicPath#1}
  
    \caption{#2}\label{#1}
    
  	
  \end{center}
\end{figure}
}
\makeatother
\providecommand{\No}{\textnumero} 


\newenvironment{thesis}{\setcounter{equation}{0}\setcounter{figure}{0}\setcounter{table}{0}\chead[Текущая секция]{\Booktitle}}{}
